"""Asynchronous cache manager designed for horizontally scaled web applications"""

__version__ = "0.5.0"

from .base import Cache  # noqa
